import { default as Alert } from './Alert.vue';
import { default as Badge } from './components/Badge/Badge.vue';
import { default as Button } from './components/Button/Button.vue';
import { default as Checkbox } from './components/Checkbox/Checkbox.vue';
import { default as Chip } from './Chip.vue';
import { default as Collapse } from './Collapse.vue';
import { default as Collapsible } from './components/Collapsible/Collapsible.vue';
import { Component } from 'vue';
import { default as Dialog } from './Dialog.vue';
import { default as Dropdown } from './components/Dropdown/Dropdown.vue';
import { default as DropdownItem } from './components/Dropdown/DropdownItem.vue';
import { default as HoverCard } from './HoverCard.vue';
import { default as HoverCardTarget } from './HoverCardTarget.vue';
import { default as Indicator } from './Indicator.vue';
import { InjectionKey } from 'vue';
import { default as ListItem } from './components/ListItem/ListItem.vue';
import { default as Loader } from './Loader.vue';
import { Placement } from '@floating-ui/vue';
import { default as Progress } from './Progress.vue';
import { default as Radio } from './components/Radio/Radio.vue';
import { Ref } from 'vue';
import { default as SegmentedControl } from './components/SegmentedControl/SegmentedControl.vue';
import { default as Select } from './components/Select/Select.vue';
import { default as TextInput } from './TextInput.vue';

export { Alert }

export declare interface AlertProps {
    /** Title of the alert */
    title?: string;
    /** Main content of the alert */
    message?: string;
    /** Icon to display */
    icon?: string;
    /** Alert variant */
    variant?: VariantType;
    /** Color of the alert */
    color?: ColorVariant;
    /** Size of the alert */
    size?: ComponentSize;
    /** Whether to show close button */
    closable?: boolean;
    /** Callback when alert is closed */
    onClose?: () => void;
    /** Whether the alert is disabled */
    disabled?: boolean;
    /** Whether the alert is in loading state */
    loading?: boolean;
    /** Whether the alert is in valid state */
    valid?: boolean;
    /** Whether the alert is in invalid state */
    invalid?: boolean;
    /** Custom classes */
    class?: string;
}

export { Badge }

export declare interface BadgeProps {
    /** Controls font-size, height and horizontal padding */
    size?: ComponentSize;
    /** If set, badge min-width becomes equal to its height and horizontal padding is removed */
    circle?: boolean;
    /** Controls border-radius */
    radius?: ComponentRadius;
    /** Badge color */
    color?: ThemeColor;
    /** Gradient configuration used when variant="gradient" */
    gradient?: {
        from: string;
        to: string;
        deg?: number;
    };
    /** Content displayed on the left side of the badge label */
    leftSection?: string | Component;
    /** Content displayed on the right side of the badge label */
    rightSection?: string | Component;
    /** Determines whether Badge should take 100% of its parent width */
    fullWidth?: boolean;
    /** Badge variant */
    variant?: BadgeVariant;
}

export declare type BadgeVariant = 'filled' | 'light' | 'outline' | 'dot' | 'transparent' | 'white' | 'default' | 'gradient';

export { Button }

export declare type ButtonColor = NonNullable<ButtonProps['color']>;

export declare interface ButtonLoaderProps {
    color?: MantineColor;
    size?: MantineSize | number;
    variant?: 'oval' | 'dots' | 'bars';
}

export declare interface ButtonProps {
    /** Button variant */
    variant?: ButtonVariant;
    /** Button color */
    color?: ThemeColor;
    /** Button size */
    size?: ComponentSize;
    /** Border radius */
    radius?: ComponentRadius;
    /** Disabled state */
    disabled?: boolean;
    /** Loading state */
    loading?: boolean;
    /** Full width button */
    fullWidth?: boolean;
    /** Custom class names */
    class?: string;
    /** Button type */
    type?: 'button' | 'submit' | 'reset';
    /** Left section content */
    leftSection?: any;
    /** Right section content */
    rightSection?: any;
    /** Props passed to left section */
    leftSectionProps?: SectionProps;
    /** Props passed to right section */
    rightSectionProps?: SectionProps;
    onClick?: (event: MouseEvent) => any;
}

export declare type ButtonRadius = NonNullable<ButtonProps['radius']>;

export declare type ButtonSize = NonNullable<ButtonProps['size']>;

declare type ButtonVariant = 'filled' | 'light' | 'outline' | 'subtle' | 'gradient' | 'white' | 'default';

export { Checkbox }

export declare interface CheckboxProps {
    modelValue?: boolean | any[];
    value?: string | number;
    id?: string;
    label?: string;
    color?: ColorVariant;
    size?: Size;
    radius?: 'sm' | 'md' | 'lg' | 'full';
    labelPosition?: 'left' | 'right';
    description?: string;
    error?: string;
    disabled?: boolean;
    indeterminate?: boolean;
    iconColor?: ColorVariant;
    autoContrast?: boolean;
    variant?: CheckboxVariant;
}

export declare type CheckboxVariant = 'filled' | 'outlined';

export { Chip }

declare type ChipColor = 'primary' | 'secondary' | 'success' | 'warning' | 'danger' | 'info' | 'dark' | 'light';

export declare interface ChipProps {
    /**
     * Model value for v-model binding
     */
    modelValue?: boolean;
    /**
     * The label text to display inside the chip
     */
    label?: string;
    /**
     * The size of the chip
     * @default 'md'
     */
    size?: ChipSize;
    /**
     * The variant style of the chip
     * @default 'filled'
     */
    variant?: ChipVariant;
    /**
     * The color theme of the chip
     * @default 'primary'
     */
    color?: ChipColor;
    /**
     * Whether the chip is disabled
     * @default false
     */
    disabled?: boolean;
    /**
     * Whether to show the check icon
     * @default true
     */
    withCheckIcon?: boolean;
    /**
     * Whether the chip appears in a loading state
     * @default false
     */
    loading?: boolean;
    /**
     * Whether the chip can be unchecked after being checked
     * @default true
     */
    allowDeselect?: boolean;
}

declare type ChipSize = 'xs' | 'sm' | 'md' | 'lg' | 'xl';

declare type ChipVariant = 'filled' | 'outline' | 'light';

export { Collapse }

export declare interface CollapseProps {
    /** Whether the collapse is open */
    open?: boolean;
    /** Collapse content */
    children?: any;
    /** Animation duration in milliseconds */
    duration?: number;
    /** Custom class names */
    class?: string;
    /** Size of the collapse spacing */
    size?: ComponentSize;
    /** Whether to disable transitions */
    disableTransition?: boolean;
}

export { Collapsible }

export declare interface CollapsibleProps {
    defaultOpen?: boolean;
    disabled?: boolean;
    class?: string;
    hideArrow?: boolean;
    buttonClass?: string;
    selectedClass?: string;
    modelValue?: boolean;
}

declare type ColorVariant = 'primary' | 'secondary' | 'success' | 'warning' | 'danger' | 'info' | 'dark' | 'light';

declare type ComponentRadius = 'none' | 'xs' | 'sm' | 'md' | 'lg' | 'xl' | 'full';

declare type ComponentSize = 'xs' | 'sm' | 'md' | 'lg' | 'xl';

export declare const composables: {};

export { Dialog }

export declare interface DialogProps {
    /** Dialog title */
    title?: string;
    /** Dialog content */
    content?: string;
    /** Whether the dialog is opened */
    opened: boolean;
    /** Dialog size */
    size?: ComponentSize;
    /** Whether to show close button */
    withCloseButton?: boolean;
    /** Called when close button is clicked */
    onClose?: () => void;
    /** Position of the dialog */
    position?: {
        top?: number | string;
        right?: number | string;
        bottom?: number | string;
        left?: number | string;
    };
    /** Whether to keep the component mounted when hidden */
    keepMounted?: boolean;
    /** Color variant */
    color?: ThemeColor;
    /** z-index value */
    zIndex?: number;
}

export { Dropdown }

export { DropdownItem }

export declare interface DropdownItemProps {
    /** Size of the dropdown item */
    size?: ComponentSize;
    /** Whether the item is disabled */
    disabled?: boolean;
    /** Whether to close dropdown on click */
    closeOnClick?: boolean;
    /** Custom classes for the item */
    class?: string;
}

export declare interface DropdownProps {
    /** Size of the dropdown */
    size?: ComponentSize;
    /** Border radius of the dropdown */
    radius?: ComponentRadius;
    /** Color theme of the dropdown */
    color?: ThemeColor;
    /** Whether the dropdown is open */
    open?: boolean;
    /** Whether the dropdown is disabled */
    disabled?: boolean;
    /** Text to show when dropdown is disabled */
    disabledText?: string;
    /** Custom classes for the dropdown button */
    buttonClasses?: string;
    /** Custom classes for the dropdown container */
    dropdownClasses?: string;
    /** Placement of the dropdown (top or bottom) */
    placement?: 'top' | 'bottom';
    /** Whether to show the dropdown arrow */
    showArrow?: boolean;
    /** Whether the parent should have relative positioning */
    parentPositionRelative?: boolean;
}

export { HoverCard }

export declare interface HoverCardContext {
    isOpen: Ref<boolean>;
    open: () => void;
    close: () => void;
}

export declare interface HoverCardDropdownProps {
    /** Additional classes for the dropdown */
    class?: string;
}

export declare const hoverCardInjectionKey: InjectionKey<HoverCardContext>;

export declare interface HoverCardProps {
    /** Initial opened state */
    initiallyOpened?: boolean;
    /** Open delay in ms */
    openDelay?: number;
    /** Close delay in ms */
    closeDelay?: number;
    /** Placement of the dropdown */
    placement?: Placement;
    /** Called when dropdown opens */
    onOpen?: () => void;
    /** Called when dropdown closes */
    onClose?: () => void;
    /** Offset from the target */
    offset?: number;
    /** Whether to disable the hover card */
    disabled?: boolean;
    /** Size of the hover card */
    size?: ComponentSize;
    /** Whether to show arrow */
    withArrow?: boolean;
    /** Arrow offset */
    arrowOffset?: number;
    /** Whether to trap focus inside dropdown */
    trapFocus?: boolean;
    /** z-index value */
    zIndex?: number;
}

export { HoverCardTarget }

export declare interface HoverCardTargetProps {
    /** Whether to use the wrapper div */
    withWrapper?: boolean;
    /** Additional classes for the wrapper */
    wrapperClass?: string;
}

export { Indicator }

export declare interface IndicatorProps {
    /** Position of the indicator relative to its container */
    position?: Position;
    /** Size of the indicator */
    size?: ComponentSize;
    /** Border radius of the indicator */
    radius?: ComponentRadius;
    /** Color variant of the indicator */
    color?: ThemeColor;
    /** Variant style of the indicator */
    variant?: 'filled' | 'light' | 'outline' | 'default' | 'subtle';
    /** Offset from the edge of the container */
    offset?: number;
    /** Whether the indicator should be inline */
    inline?: boolean;
    /** Content to be displayed inside the indicator */
    label?: string | number;
    /** Whether to show a border around the indicator */
    withBorder?: boolean;
    /** Whether the indicator is disabled */
    disabled?: boolean;
    /** Whether to show processing animation */
    processing?: boolean;
    /** Z-index of the indicator */
    zIndex?: number;
}

export declare type JustifyContent = 'start' | 'center' | 'end' | 'space-between';

export { ListItem }

export declare interface ListItemProps {
    disabled?: boolean;
    selected?: boolean;
    class?: string;
    selectedClass?: string;
}

export { Loader }

export declare interface LoaderProps {
    /** Loader variant */
    variant?: LoaderVariant;
    /** Loader color */
    color?: ThemeColor;
    /** Loader size */
    size?: ComponentSize;
    /** Custom class names */
    class?: string;
}

export declare type LoaderVariant = 'oval' | 'dots' | 'bars';

export declare type MantineColor = 'primary' | 'secondary' | 'success' | 'warning' | 'danger' | 'info' | 'dark' | 'light';

export declare type MantineGradient = {
    from: string;
    to: string;
    deg?: number;
};

export declare type MantineRadius = 'none' | 'sm' | 'md' | 'lg' | 'full' | number;

export declare type MantineSize = 'xs' | 'sm' | 'md' | 'lg' | 'xl';

declare type Position = 'top-start' | 'top-end' | 'top-center' | 'bottom-start' | 'bottom-end' | 'bottom-center' | 'middle-start' | 'middle-end' | 'middle-center';

export { Progress }

export declare interface ProgressProps {
    /** Value of the progress (0-100) */
    value: number;
    /** Size of the progress bar */
    size?: ComponentSize;
    /** Color of the progress bar */
    color?: string;
    /** Whether to show stripes */
    striped?: boolean;
    /** Whether to animate the stripes */
    animated?: boolean;
    /** Label to show inside the progress bar */
    label?: string;
    /** Custom classes */
    class?: string;
}

export declare interface ProgressSectionProps {
    value: number;
    color?: string;
    striped?: boolean;
    animated?: boolean;
}

export { Radio }

export declare interface RadioProps {
    /**
     * Value of the radio group (v-model)
     */
    modelValue?: any;
    /**
     * Value of the radio button
     */
    value?: any;
    /**
     * Label of the radio button
     */
    label?: string;
    /**
     * Color variant of the radio button
     */
    color?: ThemeColor;
    /**
     * Size of the radio button
     */
    size?: ComponentSize;
    /**
     * Whether the radio button is disabled
     */
    disabled?: boolean;
    /**
     * Description text
     */
    description?: string;
    /**
     * Error message
     */
    error?: string;
    /**
     * Position of the label
     */
    labelPosition?: 'left' | 'right';
    /**
     * Visual variant of the radio button
     * @default 'filled'
     */
    variant?: RadioVariant;
    /**
     * Custom color for the radio icon
     */
    iconColor?: string;
    /**
     * Unique identifier
     */
    id?: string;
}

export declare type RadioVariant = 'filled' | 'outlined';

declare type SectionProps = Record<string, any>;

export { SegmentedControl }

export declare interface SegmentedControlOption {
    value: string;
    label: string | number;
    disabled?: boolean;
}

export declare interface SegmentedControlProps {
    /**
     * Model value for v-model binding
     */
    modelValue?: string;
    /**
     * Array of options to display
     */
    data: (string | SegmentedControlOption)[];
    /**
     * Size of the control
     * @default 'md'
     */
    size?: 'xs' | 'sm' | 'md' | 'lg' | 'xl';
    /**
     * Border radius
     * @default 'md'
     */
    radius?: 'none' | 'sm' | 'md' | 'lg' | 'xl' | 'full';
    /**
     * Color variant
     * @default 'primary'
     */
    color?: 'primary' | 'secondary' | 'success' | 'warning' | 'danger' | 'info' | 'dark' | 'light';
    /**
     * Whether the control is disabled
     * @default false
     */
    disabled?: boolean;
    /**
     * Whether the control should take full width
     * @default false
     */
    fullWidth?: boolean;
    /**
     * Transition duration in milliseconds
     * @default 200
     */
    transitionDuration?: number;
    /**
     * Whether to show borders between items
     * @default true
     */
    withItemsBorders?: boolean;
    /**
     * Orientation of the control
     * @default 'horizontal'
     */
    orientation?: 'horizontal' | 'vertical';
}

export { Select }

export declare interface SelectOption {
    value: string;
    label: string;
    disabled?: boolean;
}

export declare interface SelectProps {
    modelValue?: string | null;
    options: SelectOption[];
    placeholder?: string;
    disabled?: boolean;
    searchable?: boolean;
    clearable?: boolean;
    loading?: boolean;
    error?: boolean;
    size?: 'xs' | 'sm' | 'md' | 'lg' | 'xl';
    radius?: 'xs' | 'sm' | 'md' | 'lg' | 'xl' | 'none';
    variant?: 'filled' | 'outline';
    color?: 'primary' | 'secondary' | 'success' | 'warning' | 'danger' | 'info' | 'dark' | 'light';
    withCheckIcon?: boolean;
    checkIconPosition?: 'left' | 'right';
    nothingFoundMessage?: string;
}

declare type Size = 'xs' | 'sm' | 'md' | 'lg' | 'xl';

export { TextInput }

export declare interface TextInputProps {
    /** Input's id attribute */
    id?: string;
    /** Input's type attribute */
    type?: string;
    /** Input's value */
    modelValue?: string;
    /** Input's placeholder */
    placeholder?: string;
    /** Disabled state */
    disabled?: boolean;
    /** Input label */
    label?: string;
    /** Label props */
    labelProps?: SectionProps;
    /** Description text shown below the input */
    description?: string;
    /** Description props */
    descriptionProps?: SectionProps;
    /** Error message */
    error?: string;
    /** Error props */
    errorProps?: SectionProps;
    /** Props passed to root element */
    wrapperProps?: SectionProps;
    /** Props passed to input element */
    inputProps?: SectionProps;
    /** Input size */
    size?: ComponentSize;
    /** Border-radius value */
    radius?: ComponentRadius;
    /** Determines whether required asterisk should be rendered */
    required?: boolean;
    /** Show asterisk even if field is not required */
    withAsterisk?: boolean;
    /** Display error state */
    withError?: boolean;
    /** Right section content */
    rightSection?: any;
    /** Props passed to right section */
    rightSectionProps?: SectionProps;
    /** Left section content */
    leftSection?: any;
    /** Props passed to left section */
    leftSectionProps?: SectionProps;
}

declare type ThemeColor = 'primary' | 'secondary' | 'success' | 'warning' | 'danger' | 'info' | 'dark' | 'light';

export declare function useHoverCard(options?: UseHoverCardOptions): {
    isOpen: Ref<boolean, boolean>;
    open: () => void;
    close: () => void;
};

declare interface UseHoverCardOptions {
    openDelay?: number;
    closeDelay?: number;
    onOpen?: () => void;
    onClose?: () => void;
    initiallyOpened?: boolean;
}

declare type VariantType = 'filled' | 'light' | 'outline' | 'default' | 'subtle' | 'gradient' | 'white' | 'dot' | 'bordered' | 'bordered-transparent' | 'text';

export { }
